@@ -34,7 +34,7 @@ from random import randint
 from micropython import const
 from .matcher import MQTTMatcher
 
-__version__ = "6.0.0"
+__version__ = "6.0.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MiniMQTT.git"
 
 # Client-specific variables
@@ -896,7 +896,7 @@ class MQTT:
 
         # Block while we parse the rest of the response
         self._sock.settimeout(timeout)
-        if res in [None, b""]:
+        if res in [None, b"", b"\x00"]:
             # If we get here, it means that there is nothing to be received
             return None
         if res[0] == MQTT_PINGRESP:
